<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       http://example.com
 * @since      1.0.0
 *
 * @package    Ela_Content_Terminal
 * @subpackage Ela_Content_Terminal/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Ela_Content_Terminal
 * @subpackage Ela_Content_Terminal/admin
 * @author     Your Name <email@example.com>
 */
class Ela_Content_Terminal_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $ela_content_terminal    The ID of this plugin.
	 */
	private $ela_content_terminal;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $ela_content_terminal       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $ela_content_terminal, $version ) {

		$this->ela_content_terminal = $ela_content_terminal;
		$this->version = $version;
		$this->init_ajax();

	}

	/**
	 * Register the Ajax Endpoints for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function init_ajax()
	{
		add_action('wp_ajax_ela_content_terminal_accept_terms', array($this, 'ela_content_terminal_accept_terms'));
		add_action('wp_ajax_ela_content_terminal_save_token', array($this, 'ela_content_terminal_save_token'));
	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {
		$current_screen = get_current_screen();
		if (strpos($current_screen->base, '-content-terminal') !== false) {
			wp_enqueue_style($this->ela_content_terminal, plugin_dir_url(__FILE__) . 'css/tailwind.css', array(), $this->version, 'all');
		}
		wp_enqueue_style( $this->ela_content_terminal, plugin_dir_url( __FILE__ ) . 'css/ela-content-terminal-admin.css', array(), $this->version, 'all' );
	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {
		wp_enqueue_script( $this->ela_content_terminal, plugin_dir_url( __FILE__ ) . 'js/ela-content-terminal-admin.js', array( 'jquery' ), $this->version, false );
	}

	/**
	 * ender_content_terminal_accept_terms function.
	 *
	 * @since    1.0.0
	 */
	public function ela_content_terminal_accept_terms()
	{
		if (!get_option('ela_content_terminal_accepted_terms')) {
			add_option('ela_content_terminal_accepted_terms', sanitize_text_field($_POST['accepted']));
			echo "Thank you for accepting the terms.";
		} else {
			update_option('ela_content_terminal_accepted_terms', sanitize_text_field($_POST['accepted']));
			echo "Thank you for accepting the terms.";
		}
		wp_die();
	}

	/**
	 * ela_content_terminal_save_token function.
	 *
	 * @since    1.0.0
	 */
	public function ela_content_terminal_save_token()
	{
		if (!get_option('ela_content_terminal_token')) {
			add_option('ela_content_terminal_token', sanitize_text_field($_POST['plugin_token']));
			echo "saved";
		}else{
			update_option('ela_content_terminal_token', sanitize_text_field($_POST['plugin_token']));
			echo "updated";
		}
		wp_die();
	}

	/**
	 * Admin Menu.
	 *
	 * @since    1.0.0
	 */
	public function ela_content_terminal_custom_menu()
	{
		add_menu_page(
			'ElderLawAnswers Content Terminal Settings',
			'ElderLawAnswers Content Terminal',
			'activate_plugins',
			'ela-content-terminal-index',
			array($this, 'get_admin_index'),
			'dashicons-plugins-checked',
			100
		);
		add_submenu_page('myplugin/myplugin-admin-page.php', 'My Sub Level Menu Example', 'Sub Level Menu', 'manage_options', 'myplugin/myplugin-admin-sub-page.php', 'myplguin_admin_sub_page');
	}

	/**
	 * get_admin_index function.
	 *
	 * @since    1.0.0
	 */
	public function get_admin_index()
	{
		$ela_content_terminal_accepted_terms = get_option('ela_content_terminal_accepted_terms');
		$ela_content_terminal_token = get_option('ela_content_terminal_token');
		include(ELA_CONTENT_TERMINAL_PLUGIN_PATH . 'admin/templates/index.php');
	}
}
