<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://elderlawanswers.com
 * @since             1.0.0
 * @package           Ela_Content_Terminal
 *
 * @wordpress-plugin
 * Plugin Name:       ElderLawAnswers Content Terminal
 * Description:       ElderLawAnswers Content Terminal allows you to include the latest news as well as choose the articles most relevant to your clientele from our extensive library.
 * Version:           1.0.5
 * Author:            Elderlawanswers
 * Author URI:        https://elderlawanswers.com
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       elderlawanswers-content-terminal
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'ELA_CONTENT_TERMINAL_VERSION', '1.0.5' );

define('ELA_CONTENT_TERMINAL_PLUGIN_PATH', trailingslashit(plugin_dir_path(__FILE__)));

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-ela-content-terminal-activator.php
 */
function activate_ela_content_terminal() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-ela-content-terminal-activator.php';
	Ela_Content_Terminal_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-ela-content-terminal-deactivator.php
 */
function deactivate_ela_content_terminal() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-ela-content-terminal-deactivator.php';
	Ela_Content_Terminal_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_ela_content_terminal' );
register_deactivation_hook( __FILE__, 'deactivate_ela_content_terminal' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-ela-content-terminal.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_ela_content_terminal() {

	$plugin = new Ela_Content_Terminal();
	$plugin->run();

}
run_ela_content_terminal();
